"""
We inmediatly need a developer to help us!

At this folder we included some files that we attepted to implement in the
past, but failed. Is there a way to fix them? Try to find a solution! If you do,
send an email to this address:

     dr01191115@gmail.com

Please try it!

--------------------------------------------------------------------------------
Troubled files for version 0.2.4

console.py: The console script "aleat3" comes from here. Is there a problem?
"""
